"""
RCK Python SDK

An elegant Python SDK for accessing RCK (Relational Calculate Kernel) API services.

Main features:
- Text computation and analysis
- Image generation and rendering
- Multimodal resource processing
- Custom output formats

Usage example:
    from rck_sdk import RCKClient
    
    client = RCKClient(api_key="your-api-key")
    
    # Text computation
    result = client.compute.analyze(
        text="Moonlight before my bed, looks like frost on the ground",
        task="Analyze the emotion and theme of the poetry"
    )
    
    # Image generation
    image = client.image.generate(
        prompt="Landscape in traditional painting style",
        style="Traditional ink wash painting"
    )
"""

from .client import RCKClient
from .core.exceptions import (
    RCKError,
    AuthenticationError,
    ValidationError,
    APIError
)

# Version information
__version__ = "1.0.1"
__author__ = "RCK Team"
__email__ = "support@rck.ai"

# Export main APIs
__all__ = [
    "RCKClient",
    "RCKError", 
    "AuthenticationError",
    "ValidationError",
    "APIError",
    "__version__"
] 