"""
Common output format Schema definitions
"""

from typing import Dict, Any

# Predefined common output formats
PREDEFINED_SCHEMAS = {
    "basic_analysis": {
        "type": "object",
        "properties": {
            "emotion": {"type": "string", "description": "Sentiment analysis result"},
            "theme": {"type": "string", "description": "Theme analysis"},
            "analysis": {"type": "string", "description": "Detailed analysis"}
        },
        "required": ["emotion", "theme", "analysis"]
    },
    
    "poem_creation": {
        "type": "object", 
        "properties": {
            "poem": {"type": "string", "description": "Created poetry"},
            "creative_process": {"type": "string", "description": "Creative process"},
            "style_notes": {"type": "string", "description": "Style notes"}
        },
        "required": ["poem"]
    },
    
    "scene_description": {
        "type": "object",
        "properties": {
            "scene_description": {
                "type": "object",
                "properties": {
                    "main_subjects": {"type": "string", "description": "Main subjects and spatial relationships"},
                    "lighting": {"type": "string", "description": "Lighting conditions and atmosphere"},
                    "composition": {"type": "string", "description": "Image composition"},
                    "style": {"type": "string", "description": "Artistic style"}
                },
                "required": ["main_subjects", "lighting", "composition", "style"]
            }
        },
        "required": ["scene_description"]
    },
    
    "translation": {
        "type": "object",
        "properties": {
            "translation": {"type": "string", "description": "Translation result"},
            "original_language": {"type": "string", "description": "Source language"},
            "target_language": {"type": "string", "description": "Target language"},
            "cultural_notes": {"type": "string", "description": "Cultural background notes"}
        },
        "required": ["translation"]
    }
}

def get_schema(schema_name: str) -> Dict[str, Any]:
    """Get predefined Schema"""
    if schema_name not in PREDEFINED_SCHEMAS:
        raise ValueError(f"Unknown Schema name: {schema_name}")
    return PREDEFINED_SCHEMAS[schema_name].copy()