"""
Authentication management module
"""

from typing import Optional
from .exceptions import AuthenticationError

class AuthManager:
    """Authentication manager"""
    
    def __init__(self, api_key: str):
        """
        Initialize authentication manager
        
        :param api_key: Topos API key
        """
        if not api_key:
            raise AuthenticationError("API key cannot be empty")
        
        if not isinstance(api_key, str):
            raise AuthenticationError("API key must be string type")
        
        # Simple API key format validation
        if len(api_key) < 10:
            raise AuthenticationError("Invalid API key format")
        
        self.api_key = api_key
    
    def get_auth_headers(self) -> dict:
        """Get authentication request headers"""
        return {
            "topos-api-key": self.api_key
        }
    
    def validate_key(self) -> bool:
        """Validate API key format (basic validation)"""
        return bool(self.api_key and len(self.api_key) >= 10) 