"""
RCK SDK custom exception classes
"""

class RCKError(Exception):
    """RCK SDK base exception class"""
    def __init__(self, message: str, error_code: str = None):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

class AuthenticationError(RCKError):
    """Authentication failure exception"""
    def __init__(self, message: str = "Authentication failed, please check API key"):
        super().__init__(message, "AUTH_FAILED")

class ValidationError(RCKError):
    """Parameter validation failure exception"""
    def __init__(self, message: str, field: str = None):
        super().__init__(message, "VALIDATION_ERROR")
        self.field = field

class APIError(RCKError):
    """API request failure exception"""
    def __init__(self, message: str, status_code: int = None, response_data: dict = None):
        super().__init__(message, "API_ERROR")
        self.status_code = status_code
        self.response_data = response_data

class NetworkError(RCKError):
    """Network connection exception"""
    def __init__(self, message: str = "Network connection failed"):
        super().__init__(message, "NETWORK_ERROR")

class TimeoutError(RCKError):
    """Request timeout exception"""
    def __init__(self, message: str = "Request timeout"):
        super().__init__(message, "TIMEOUT_ERROR") 