"""
Request data models
"""

from typing import Dict, Any, List, Optional
from dataclasses import dataclass

@dataclass
class ComputeRequest:
    """Text computation request model"""
    start_point: str
    expect_path: str
    output_schema: Optional[Dict[str, Any]] = None
    custom_fields: Optional[Dict[str, str]] = None
    resources: Optional[List[Dict[str, str]]] = None
    
    def to_dict(self) -> Dict[str, Any]:
        """Convert to API request format"""
        # Build start_point
        start_point_obj = {"startPoint": self.start_point}
        if self.resources:
            start_point_obj["resource"] = self.resources
        
        # Build path
        path_obj = {"expectPath": self.expect_path}
        
        # Add output format
        if self.output_schema:
            import json
            path_obj["endpointClass"] = json.dumps(self.output_schema)
        else:
            # Default output format
            path_obj["endpointClass"] = '{"type": "object", "properties": {"emotion": {"type": "string"}, "theme": {"type": "string"}, "analysis": {"type": "string"}}}'
        
        # Add custom fields
        if self.custom_fields:
            path_obj.update(self.custom_fields)
        
        return {
            "start_point": start_point_obj,
            "path": path_obj
        }

@dataclass
class ImageRequest:
    """Image generation request model"""
    start_point: str
    composition: str
    lighting: str
    style: str
    
    def to_dict(self) -> Dict[str, Any]:
        """Convert to API request format"""
        return {
            "start_point": {
                "startPoint": self.start_point
            },
            "path": {
                "frame_Composition": self.composition,
                "lighting": self.lighting,
                "style": self.style
            }
        } 