"""
SDK logging configuration
"""

import logging
import sys
from typing import Optional

def setup_logger(
    name: str = "rck_sdk",
    level: int = logging.INFO,
    format_string: Optional[str] = None
) -> logging.Logger:
    """
    Setup SDK logger
    
    :param name: Logger name
    :param level: Log level
    :param format_string: Custom log format
    :return: Configured logger
    """
    logger = logging.getLogger(name)
    
    # Avoid adding handlers repeatedly
    if logger.handlers:
        return logger
    
    logger.setLevel(level)
    
    # Create console handler
    console_handler = logging.StreamHandler(sys.stdout)
    console_handler.setLevel(level)
    
    # Set log format
    if not format_string:
        format_string = '[%(asctime)s] [%(name)s] [%(levelname)s] - %(message)s'
    
    formatter = logging.Formatter(format_string, datefmt='%Y-%m-%d %H:%M:%S')
    console_handler.setFormatter(formatter)
    
    logger.addHandler(console_handler)
    
    return logger

# Default logger
default_logger = setup_logger() 